function mydrawdeltag = drawdel(c,d,f,t,n,p,s,F,dc)
% drawdel.m  DRAW DELAY
% Authors: Prof. Dr Miroslav D. Lutovac, Prof. Dr Dejan V. Tosic
% lutovac@kondor.etf.bg.ac.yu    http://kondor.etf.bg.ac.yu/~lutovac/
% tosic@galeb.etf.bg.ac.yu       http://www.rcub.bg.ac.yu/~tosicde/
% $Revision: 2.8 $  $Date: 2005/03/04$
% Copyright 1999-2005 Miroslav D. Lutovac and Dejan V. Tosic
% This file is part of DrawFilt.
% DrawFilt is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2 of the License, or
% any later version.
% DrawFilt is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU General Public License for more details.
% You should have received a copy of the GNU General Public License
% along with DrawFilt; if not, write to the Free Software
% Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
% DrawFilt is distributed with the GNU General Public License.
% This licence is contained in the file LICENCE.TXT.
% References:
% Miroslav D. Lutovac, Dejan V. Tosic, Brian L. Evans
% Filter Design for Signal Processing Using MATLAB and Mathematica
% Prentice Hall, ISBN 0-201-36130-2 
%
% drawdel(c,d,f,t,n,p,s,F)
% c = x1 
% d = y1
% f = x2 or y2
% t = text      "D"
% n = exponent  z^(-n)
% p = orientation: 
%         input ->-D--- output
%     0 = left  ->-D--- right
%     1 = down  ->-D--- up
%     2 = right ->-D--- left
%     3 = up    ->-D--- down
%     ...
%    14 = left  ->-D->- right
%    15 = down  ->-D->- up
%    12 = right ->-D->- left
%    11 = up    ->-D->- down
% s = scale
% F = font size 
% dc= draw color
                         
mydrawdeltag = ['drawdelx' num2str(c) 'y' num2str(d)  'z' num2str(f) 'p' num2str(p)];


a=(f+c)/2-0.4*s;
b=d;
g=c;
h=(f+d)/2-0.4*s;

if p == 0
 x = a + s*[(c-a)/s, 0.1, 0.1, 0.7, 0.7, 0.1, 0.1, 0.7, 0.7, (f-a)/s];
 y = b + s*[      0,   0, 0.3, 0.3,-0.3,-0.3, 0.3, 0.3,   0,0];
 line(x,y,'Color',dc,'Tag',mydrawdeltag);
 x1 = a + s*[-0.05, 0.05, -0.05]; y1 = b + s*[ 0.05,    0, -0.05];

 line(x1,y1,'Color',dc,'Tag',mydrawdeltag)
 text(a+s*0.4,b+s*0.4,t,'FontName','Times','FontSize',F,...
   'HorizontalAlignment','center','VerticalAlignment','bottom','Tag',mydrawdeltag)
 text(a+s*0.4,b,'z','FontName','Times-Italic','FontSize',F,...
   'HorizontalAlignment','right','VerticalAlignment','middle','Tag',mydrawdeltag)
 text(a+s*0.4,b,n,'FontName','Times','FontSize',F-1,...
   'HorizontalAlignment','left','VerticalAlignment','bottom','Tag',mydrawdeltag)
elseif p == 1
 x = g + s*[0,0,0.3,0.3,-0.3,-0.3,0.3,0.3,0,0];
 y = h + s*[(d-h)/s,0.1,0.1,0.7,0.7,0.1,0.1,0.7,0.7,(f-h)/s];
 line(x,y,'Color',dc,'Tag',mydrawdeltag)
 x1 = g + s*[0.05,0,-0.05]; y1 = h + s*[-0.05,0.05,-0.05];
 line(x1,y1,'Color',dc,'Tag',mydrawdeltag)
 text(g-s*0.4,h+s*0.4,t,'FontName','Times','FontSize',F,...
   'HorizontalAlignment','right','VerticalAlignment','middle','Tag',mydrawdeltag)
 text(g,h+s*0.4,'z','FontName','Times-Italic','FontSize',F,...
   'HorizontalAlignment','right','VerticalAlignment','middle','Tag',mydrawdeltag)
 text(g,h+s*0.4,n,'FontName','Times','FontSize',F-1,...
   'HorizontalAlignment','left','VerticalAlignment','bottom','Tag',mydrawdeltag)
elseif p == 2
 x = a + s*[(c-a)/s, 0.1, 0.1, 0.7, 0.7, 0.1, 0.1, 0.7, 0.7, (f-a)/s];
 y = b + s*[      0,   0, 0.3, 0.3,-0.3,-0.3, 0.3, 0.3,   0,0];
 line(x,y,'Color',dc,'Tag',mydrawdeltag)
 x1 = a + s*[0.85, 0.75, 0.85]; y1 = b + s*[0.05, 0, -0.05];
 line(x1,y1,'Color',dc,'Tag',mydrawdeltag)
 text(a+s*0.4,b-s*0.4,t,'FontName','Times','FontSize',F,...
   'HorizontalAlignment','center','VerticalAlignment','top','Tag',mydrawdeltag)
 text(a+s*0.4,b,'z','FontName','Times-Italic','FontSize',F,...
   'HorizontalAlignment','right','VerticalAlignment','middle','Tag',mydrawdeltag)
 text(a+s*0.4,b,n,'FontName','Times','FontSize',F-1,...
   'HorizontalAlignment','left','VerticalAlignment','bottom','Tag',mydrawdeltag)
elseif p == 3
 x = g + s*[0,0,0.3,0.3,-0.3,-0.3,0.3,0.3,0,0];
 y = h + s*[(d-h)/s,0.1,0.1,0.7,0.7,0.1,0.1,0.7,0.7,(f-h)/s];
 line(x,y,'Color',dc,'Tag',mydrawdeltag)
 x1 = g + s*[0.05,0,-0.05]; y1 = h + s*[0.85,0.75,0.85];
 line(x1,y1,'Color',dc,'Tag',mydrawdeltag)
 text(g+s*0.4,h+s*0.4,t,'FontName','Times','FontSize',F,...
   'HorizontalAlignment','left','VerticalAlignment','middle','Tag',mydrawdeltag)
 text(g,h+s*0.4,'z','FontName','Times-Italic','FontSize',F,...
   'HorizontalAlignment','right','VerticalAlignment','middle','Tag',mydrawdeltag)
 text(g,h+s*0.4,n,'FontName','Times','FontSize',F-1,...
   'HorizontalAlignment','left','VerticalAlignment','bottom','Tag',mydrawdeltag)
elseif p == 4
 x = a + s*[(c-a)/s, 0.1, 0.1, 0.7, 0.7, 0.1, 0.1, 0.7, 0.7, (f-a)/s];
 y = b + s*[      0,   0, 0.3, 0.3,-0.3,-0.3, 0.3, 0.3,   0,0];
 line(x,y,'Color',dc,'Tag',mydrawdeltag)
 x1 = a + s*[0.85, 0.75, 0.85]; y1 = b + s*[0.05, 0, -0.05];
 line(x1,y1,'Color',dc,'Tag',mydrawdeltag)
 text(a+s*0.4,b+s*0.4,t,'FontName','Times','FontSize',F,...
   'HorizontalAlignment','center','VerticalAlignment','bottom','Tag',mydrawdeltag)
 text(a+s*0.4,b,'z','FontName','Times-Italic','FontSize',F,...
   'HorizontalAlignment','right','VerticalAlignment','middle','Tag',mydrawdeltag)
 text(a+s*0.4,b,n,'FontName','Times','FontSize',F-1,...
   'HorizontalAlignment','left','VerticalAlignment','bottom','Tag',mydrawdeltag)
elseif p == 5
 x = g + s*[0,0,0.3,0.3,-0.3,-0.3,0.3,0.3,0,0];
 y = h + s*[(d-h)/s,0.1,0.1,0.7,0.7,0.1,0.1,0.7,0.7,(f-h)/s];
 line(x,y,'Color',dc,'Tag',mydrawdeltag)
 x1 = g + s*[0.05,0,-0.05]; y1 = h + s*[0.85,0.75,0.85];
 line(x1,y1,'Color',dc,'Tag',mydrawdeltag)
 text(g-s*0.4,h+s*0.4,t,'FontName','Times','FontSize',F,...
   'HorizontalAlignment','right','VerticalAlignment','middle','Tag',mydrawdeltag)
 text(g,h+s*0.4,'z','FontName','Times-Italic','FontSize',F,...
   'HorizontalAlignment','right','VerticalAlignment','middle','Tag',mydrawdeltag)
 text(g,h+s*0.4,n,'FontName','Times','FontSize',F-1,...
   'HorizontalAlignment','left','VerticalAlignment','bottom','Tag',mydrawdeltag)
elseif p == 6
 x = a + s*[(c-a)/s, 0.1, 0.1, 0.7, 0.7, 0.1, 0.1, 0.7, 0.7, (f-a)/s];
 y = b + s*[      0,   0, 0.3, 0.3,-0.3,-0.3, 0.3, 0.3,   0,0];
 line(x,y,'Color',dc,'Tag',mydrawdeltag)
 x1 = a + s*[-0.05, 0.05, -0.05]; y1 = b + s*[ 0.05,    0, -0.05];
 line(x1,y1,'Color',dc,'Tag',mydrawdeltag)
 text(a+s*0.4,b-s*0.4,t,'FontName','Times','FontSize',F,...
   'HorizontalAlignment','center','VerticalAlignment','top','Tag',mydrawdeltag)
 text(a+s*0.4,b,'z','FontName','Times-Italic','FontSize',F,...
   'HorizontalAlignment','right','VerticalAlignment','middle','Tag',mydrawdeltag)
 text(a+s*0.4,b,n,'FontName','Times','FontSize',F-1,...
   'HorizontalAlignment','left','VerticalAlignment','bottom','Tag',mydrawdeltag)
elseif p == 7
 x = g + s*[0,0,0.3,0.3,-0.3,-0.3,0.3,0.3,0,0];
 y = h + s*[(d-h)/s,0.1,0.1,0.7,0.7,0.1,0.1,0.7,0.7,(f-h)/s];
 line(x,y,'Color',dc,'Tag',mydrawdeltag)
 x1 = g + s*[0.05,0,-0.05]; y1 = h + s*[-0.05,0.05,-0.05];
 line(x1,y1,'Color',dc,'Tag',mydrawdeltag)
 text(g+s*0.4,h+s*0.4,t,'FontName','Times','FontSize',F,...
   'HorizontalAlignment','left','VerticalAlignment','middle','Tag',mydrawdeltag)
 text(g,h+s*0.4,'z','FontName','Times-Italic','FontSize',F,...
   'HorizontalAlignment','right','VerticalAlignment','middle','Tag',mydrawdeltag)
 text(g,h+s*0.4,n,'FontName','Times','FontSize',F-1,...
   'HorizontalAlignment','left','VerticalAlignment','bottom','Tag',mydrawdeltag)
elseif p == 8
 x = a + s*[(c-a)/s, 0.1, 0.1, 0.7, 0.7, 0.1, 0.1, 0.7, 0.7, (f-a)/s];
 y = b + s*[      0,   0, 0.3, 0.3,-0.3,-0.3, 0.3, 0.3,   0,0];
 line(x,y,'Color',dc,'Tag',mydrawdeltag)
 x1 = a + s*[-0.05, 0.05, -0.05]; y1 = b + s*[ 0.05,    0, -0.05];
 line(x1,y1,'Color',dc,'Tag',mydrawdeltag)
 x2 = a + s*[0.75,0.85,0.75]; y2 = b + s*[0.05,0,-0.05];
 line(x2,y2,'Color',dc,'Tag',mydrawdeltag)
 text(a+s*0.4,b+s*0.4,t,'FontName','Times','FontSize',F,...
   'HorizontalAlignment','center','VerticalAlignment','bottom','Tag',mydrawdeltag)
 text(a+s*0.4,b,'z','FontName','Times-Italic','FontSize',F,...
   'HorizontalAlignment','right','VerticalAlignment','middle','Tag',mydrawdeltag)
 text(a+s*0.4,b,n,'FontName','Times','FontSize',F-1,...
   'HorizontalAlignment','left','VerticalAlignment','bottom','Tag',mydrawdeltag)
elseif p == 9
 x = g + s*[0,0,0.3,0.3,-0.3,-0.3,0.3,0.3,0,0];
 y = h + s*[(d-h)/s,0.1,0.1,0.7,0.7,0.1,0.1,0.7,0.7,(f-h)/s];
 line(x,y,'Color',dc,'Tag',mydrawdeltag)
 x1 = g + s*[0.05,0,-0.05]; y1 = h + s*[-0.05,0.05,-0.05];
 line(x1,y1,'Color',dc,'Tag',mydrawdeltag)
 x2 = g + s*[0.05,0,-0.05]; y2 = h + s*[0.75,0.85,0.75];
 line(x2,y2,'Color',dc,'Tag',mydrawdeltag)
 text(g-s*0.4,h+s*0.4,t,'FontName','Times','FontSize',F,...
   'HorizontalAlignment','right','VerticalAlignment','middle','Tag',mydrawdeltag)
 text(g,h+s*0.4,'z','FontName','Times-Italic','FontSize',F,...
   'HorizontalAlignment','right','VerticalAlignment','middle','Tag',mydrawdeltag)
 text(g,h+s*0.4,n,'FontName','Times','FontSize',F-1,...
   'HorizontalAlignment','left','VerticalAlignment','bottom','Tag',mydrawdeltag)
elseif p == 10
 x = a + s*[(c-a)/s, 0.1, 0.1, 0.7, 0.7, 0.1, 0.1, 0.7, 0.7, (f-a)/s];
 y = b + s*[      0,   0, 0.3, 0.3,-0.3,-0.3, 0.3, 0.3,   0,0];
 line(x,y,'Color',dc,'Tag',mydrawdeltag)
 x1 = a + s*[0.85, 0.75, 0.85]; y1 = b + s*[0.05, 0, -0.05];
 line(x1,y1,'Color',dc,'Tag',mydrawdeltag)
 x2 = a + s*[0.05,-0.05,0.05]; y2 = b + s*[0.05,0,-0.05];
 line(x2,y2,'Color',dc,'Tag',mydrawdeltag)
 text(a+s*0.4,b-s*0.4,t,'FontName','Times','FontSize',F,...
   'HorizontalAlignment','center','VerticalAlignment','top','Tag',mydrawdeltag)
 text(a+s*0.4,b,'z','FontName','Times-Italic','FontSize',F,...
   'HorizontalAlignment','right','VerticalAlignment','middle','Tag',mydrawdeltag)
 text(a+s*0.4,b,n,'FontName','Times','FontSize',F-1,...
   'HorizontalAlignment','left','VerticalAlignment','bottom','Tag',mydrawdeltag)
elseif p == 11
 x = g + s*[0,0,0.3,0.3,-0.3,-0.3,0.3,0.3,0,0];
 y = h + s*[(d-h)/s,0.1,0.1,0.7,0.7,0.1,0.1,0.7,0.7,(f-h)/s];
 line(x,y,'Color',dc,'Tag',mydrawdeltag)
 x1 = g + s*[0.05,0,-0.05]; y1 = h + s*[0.85,0.75,0.85];
 line(x1,y1,'Color',dc,'Tag',mydrawdeltag)
 x2 = g + s*[0.05,0,-0.05]; y2 = h + s*[0.05,-0.05,0.05];
 line(x2,y2,'Color',dc,'Tag',mydrawdeltag)
 text(g+s*0.4,h+s*0.4,t,'FontName','Times','FontSize',F,...
   'HorizontalAlignment','left','VerticalAlignment','middle','Tag',mydrawdeltag)
 text(g,h+s*0.4,'z','FontName','Times-Italic','FontSize',F,...
   'HorizontalAlignment','right','VerticalAlignment','middle','Tag',mydrawdeltag)
 text(g,h+s*0.4,n,'FontName','Times','FontSize',F-1,...
   'HorizontalAlignment','left','VerticalAlignment','bottom','Tag',mydrawdeltag)
elseif p == 12
 x = a + s*[(c-a)/s, 0.1, 0.1, 0.7, 0.7, 0.1, 0.1, 0.7, 0.7, (f-a)/s];
 y = b + s*[      0,   0, 0.3, 0.3,-0.3,-0.3, 0.3, 0.3,   0,0];
 line(x,y,'Color',dc,'Tag',mydrawdeltag)
 x1 = a + s*[0.85, 0.75, 0.85]; y1 = b + s*[0.05, 0, -0.05];
 line(x1,y1,'Color',dc,'Tag',mydrawdeltag)
 x2 = a + s*[0.05,-0.05,0.05]; y2 = b + s*[0.05,0,-0.05];
 line(x2,y2,'Color',dc,'Tag',mydrawdeltag)
 text(a+s*0.4,b+s*0.4,t,'FontName','Times','FontSize',F,...
   'HorizontalAlignment','center','VerticalAlignment','bottom','Tag',mydrawdeltag)
 text(a+s*0.4,b,'z','FontName','Times-Italic','FontSize',F,...
   'HorizontalAlignment','right','VerticalAlignment','middle','Tag',mydrawdeltag)
 text(a+s*0.4,b,n,'FontName','Times','FontSize',F-1,...
   'HorizontalAlignment','left','VerticalAlignment','bottom','Tag',mydrawdeltag)
elseif p == 13
 x = g + s*[0,0,0.3,0.3,-0.3,-0.3,0.3,0.3,0,0];
 y = h + s*[(d-h)/s,0.1,0.1,0.7,0.7,0.1,0.1,0.7,0.7,(f-h)/s];
 line(x,y,'Color',dc,'Tag',mydrawdeltag)
 x1 = g + s*[0.05,0,-0.05]; y1 = h + s*[0.85,0.75,0.85];
 line(x1,y1,'Color',dc,'Tag',mydrawdeltag)
 x2 = g + s*[0.05,0,-0.05]; y2 = h + s*[0.05,-0.05,0.05];
 line(x2,y2,'Color',dc,'Tag',mydrawdeltag)
 text(g-s*0.4,h+s*0.4,t,'FontName','Times','FontSize',F,...
   'HorizontalAlignment','right','VerticalAlignment','middle','Tag',mydrawdeltag)
 text(g,h+s*0.4,'z','FontName','Times-Italic','FontSize',F,...
   'HorizontalAlignment','right','VerticalAlignment','middle','Tag',mydrawdeltag)
 text(g,h+s*0.4,n,'FontName','Times','FontSize',F-1,...
   'HorizontalAlignment','left','VerticalAlignment','bottom','Tag',mydrawdeltag)
% ,Line[({g,h}+s*#)& /@ {{0.05,0.05},{0,-0.05},{-0.05,0.05}}]
elseif p == 14
 x = a + s*[(c-a)/s, 0.1, 0.1, 0.7, 0.7, 0.1, 0.1, 0.7, 0.7, (f-a)/s];
 y = b + s*[      0,   0, 0.3, 0.3,-0.3,-0.3, 0.3, 0.3,   0,0];
 line(x,y,'Color',dc,'Tag',mydrawdeltag)
 x1 = a + s*[-0.05, 0.05, -0.05]; y1 = b + s*[ 0.05,    0, -0.05];
 line(x1,y1,'Color',dc,'Tag',mydrawdeltag)
 x2 = a + s*[0.75,0.85,0.75]; y2 = b + s*[0.05,0,-0.05];
 line(x2,y2,'Color',dc,'Tag',mydrawdeltag)
 text(a+s*0.4,b-s*0.4,t,'FontName','Times','FontSize',F,...
   'HorizontalAlignment','center','VerticalAlignment','top','Tag',mydrawdeltag)
 text(a+s*0.4,b,'z','FontName','Times-Italic','FontSize',F,...
   'HorizontalAlignment','right','VerticalAlignment','middle','Tag',mydrawdeltag)
 text(a+s*0.4,b,n,'FontName','Times','FontSize',F-1,...
   'HorizontalAlignment','left','VerticalAlignment','bottom','Tag',mydrawdeltag)
else
 x = g + s*[0,0,0.3,0.3,-0.3,-0.3,0.3,0.3,0,0];
 y = h + s*[(d-h)/s,0.1,0.1,0.7,0.7,0.1,0.1,0.7,0.7,(f-h)/s];
 line(x,y,'Color',dc,'Tag',mydrawdeltag)
 x1 = g + s*[0.05,0,-0.05]; y1 = h + s*[-0.05,0.05,-0.05];
 line(x1,y1,'Color',dc,'Tag',mydrawdeltag)
 x2 = g + s*[0.05,0,-0.05]; y2 = h + s*[0.75,0.85,0.75];
 line(x2,y2,'Color',dc,'Tag',mydrawdeltag)
 text(g+s*0.4,h+s*0.4,t,'FontName','Times','FontSize',F,...
   'HorizontalAlignment','left','VerticalAlignment','middle','Tag',mydrawdeltag)
 text(g,h+s*0.4,'z','FontName','Times-Italic','FontSize',F,...
   'HorizontalAlignment','right','VerticalAlignment','middle','Tag',mydrawdeltag)
 text(g,h+s*0.4,n,'FontName','Times','FontSize',F-1,...
   'HorizontalAlignment','left','VerticalAlignment','bottom','Tag',mydrawdeltag)
end

